@@ -186,9 +186,9 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
                       static_cast<int>(mScene->sceneRect().width()),
                       static_cast<int>(mScene->headerHeight() - dayLabelsHeight)),
                 Qt::AlignCenter,
-                QStringLiteral("%1 %2")
-                    .arg(QLocale().standaloneMonthName(dayInMonth.month(), QLocale::LongFormat))
-                    .arg(dayInMonth.year()));
+                i18nc("monthname year", "%1 %2",
+                    QLocale().standaloneMonthName(dayInMonth.month(), QLocale::LongFormat),
+                    QString::number(dayInMonth.year())));
 
     font.setPointSize(dayLabelsHeight - 10);
     p->setFont(font);
@@ -215,7 +215,7 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     */
     int columnWidth = mScene->columnWidth();
     int rowHeight = mScene->rowHeight();
-    QDate todayDate {QDate::currentDate()};
+    QDate todayDate{QDate::currentDate()};
 
     const QList<QDate> workDays = CalendarSupport::workDays(mMonthView->actualStartDateTime().date(), mMonthView->actualEndDateTime().date());
     QRect todayRect;
