@@ -13,7 +13,6 @@
 #include "todoview.h"
 
 #include "calendarview_debug.h"
-#include "incidencetreemodel.h"
 #include "tododelegates.h"
 #include "todomodel.h"
 #include "todoviewquickaddline.h"
@@ -21,20 +20,21 @@
 #include "todoviewsortfilterproxymodel.h"
 #include "todoviewview.h"
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/EntityMimeTypeFilterModel>
 #include <Akonadi/TagFetchJob>
 
 #include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/IncidenceTreeModel>
 
 #include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
-
-#include <CalendarSupport/KDatePickerPopup>
 
 #include <KCalendarCore/CalFormat>
 
 #include <KConfig>
+#include <KDatePickerPopup>
 #include <KJob>
+#include <KMessageBox>
 
 #include <QGridLayout>
 #include <QHeaderView>
@@ -105,10 +105,10 @@ public:
             todoTreeModel = nullptr;
         } else {
             delete todoTreeModel;
-            todoTreeModel = new IncidenceTreeModel(QStringList() << todoMimeType, parent);
+            todoTreeModel = new Akonadi::IncidenceTreeModel(QStringList() << todoMimeType, parent);
             for (TodoView *view : std::as_const(views)) {
-                QObject::connect(todoTreeModel, &IncidenceTreeModel::indexChangedParent, view, &TodoView::expandIndex);
-                QObject::connect(todoTreeModel, &IncidenceTreeModel::batchInsertionFinished, view, &TodoView::restoreViewState);
+                QObject::connect(todoTreeModel, &Akonadi::IncidenceTreeModel::indexChangedParent, view, &TodoView::expandIndex);
+                QObject::connect(todoTreeModel, &Akonadi::IncidenceTreeModel::batchInsertionFinished, view, &TodoView::restoreViewState);
                 view->mView->setDragDropMode(QAbstractItemView::DragDrop);
                 view->setFlatView(flat, /**propagate=*/false); // So other views update their toggle icon
             }
@@ -150,7 +150,7 @@ public:
     QObject *parent = nullptr;
 
     Akonadi::ETMCalendar::Ptr calendar;
-    IncidenceTreeModel *todoTreeModel = nullptr;
+    Akonadi::IncidenceTreeModel *todoTreeModel = nullptr;
     Akonadi::EntityMimeTypeFilterModel *todoFlatModel = nullptr;
     EventViews::PrefsPtr prefs;
 };
@@ -175,6 +175,12 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     setPreferences(prefs);
     if (!sModels) {
         sModels = new ModelStack(prefs, parent);
+        connect(sModels->todoModel, &TodoModel::dropOnSelfRejected, this, []() {
+            KMessageBox::information(nullptr,
+                                     i18n("Cannot move to-do to itself or a child of itself."),
+                                     i18n("Drop To-do"),
+                                     QStringLiteral("NoDropTodoOntoItself"));
+        });
     }
     sModels->registerView(this);
 
@@ -367,26 +373,20 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mItemPopupMenu->addSeparator();
 
-    mCopyPopupMenu = new CalendarSupport::KDatePickerPopup(CalendarSupport::KDatePickerPopup::NoDate | CalendarSupport::KDatePickerPopup::DatePicker
-                                                               | CalendarSupport::KDatePickerPopup::Words,
-                                                           QDate::currentDate(),
-                                                           this);
+    mCopyPopupMenu = new KDatePickerPopup(KDatePickerPopup::NoDate | KDatePickerPopup::DatePicker | KDatePickerPopup::Words, QDate::currentDate(), this);
     mCopyPopupMenu->setTitle(i18nc("@title:menu", "&Copy To"));
 
-    connect(mCopyPopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
+    connect(mCopyPopupMenu, &KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
 
-    connect(mCopyPopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
+    connect(mCopyPopupMenu, &KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
-    mMovePopupMenu = new CalendarSupport::KDatePickerPopup(CalendarSupport::KDatePickerPopup::NoDate | CalendarSupport::KDatePickerPopup::DatePicker
-                                                               | CalendarSupport::KDatePickerPopup::Words,
-                                                           QDate::currentDate(),
-                                                           this);
+    mMovePopupMenu = new KDatePickerPopup(KDatePickerPopup::NoDate | KDatePickerPopup::DatePicker | KDatePickerPopup::Words, QDate::currentDate(), this);
     mMovePopupMenu->setTitle(i18nc("@title:menu", "&Move To"));
 
-    connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
-    connect(mView->startPopupMenu(), &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::setStartDate);
+    connect(mMovePopupMenu, &KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
+    connect(mView->startPopupMenu(), &KDatePickerPopup::dateChanged, this, &TodoView::setStartDate);
 
-    connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
+    connect(mMovePopupMenu, &KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
     mItemPopupMenu->insertMenu(nullptr, mCopyPopupMenu);
     mItemPopupMenu->insertMenu(nullptr, mMovePopupMenu);
@@ -615,7 +615,7 @@ void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem,
         return;
     }
 
-    KCalendarCore::Todo::Ptr parent = CalendarSupport::todo(parentItem);
+    KCalendarCore::Todo::Ptr parent = Akonadi::CalendarUtils::todo(parentItem);
 
     KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
     todo->setSummary(summaryTrimmed);
@@ -674,7 +674,7 @@ void TodoView::contextMenu(QPoint pos)
                 enable = false;
             } else {
                 Akonadi::Item item = incidences.first();
-                incidencePtr = CalendarSupport::incidence(item);
+                incidencePtr = Akonadi::CalendarUtils::incidence(item);
 
                 // Action isn't RO, it can change the incidence, "Edit" for example.
                 const bool actionIsRw = mItemPopupMenuReadWriteEntries.contains(entry);
@@ -813,7 +813,7 @@ void TodoView::copyTodoToDate(QDate date)
 
     const auto origItem = sModels->todoModel->data(origIndex, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
-    const KCalendarCore::Todo::Ptr orig = CalendarSupport::todo(origItem);
+    const KCalendarCore::Todo::Ptr orig = Akonadi::CalendarUtils::todo(origItem);
     if (!orig) {
         return;
     }
@@ -857,7 +857,7 @@ QMenu *TodoView::createCategoryPopupMenu()
     }
 
     const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     const QStringList checkedCategories = todo->categories();
@@ -903,7 +903,7 @@ void TodoView::setNewDate(QDate date)
     }
 
     const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
@@ -933,7 +933,7 @@ void TodoView::setStartDate(QDate date)
     }
 
     const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
@@ -964,7 +964,7 @@ void TodoView::setNewPercentage(QAction *action)
     }
 
     const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
@@ -990,7 +990,7 @@ void TodoView::setNewPriority(QAction *action)
         return;
     }
     const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
         KCalendarCore::Todo::Ptr oldTodo(todo->clone());
         todo->setPriority(mPriority[action]);
@@ -1007,7 +1007,7 @@ void TodoView::changedCategories(QAction *action)
     }
 
     const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
         KCalendarCore::Todo::Ptr oldTodo(todo->clone());
